PALM-meteo: palmmeteo_stdplugins.wrf.WRFRadPlugin Class Reference

PALM-meteo

Public Member Functions | List of all members
palmmeteo_stdplugins.wrf.WRFRadPlugin Class Reference
Inheritance diagram for palmmeteo_stdplugins.wrf.WRFRadPlugin:
[legend]
Collaboration diagram for palmmeteo_stdplugins.wrf.WRFRadPlugin:
[legend]

## Public Member Functions
def | check_config (self, *args, **kwargs)
def | import_data (self, *args, **kwargs)
def | import_data (self, *args, **kwargs)
def | check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
def | __new__ (cls, name, bases, dct)

## Member Function Documentation

## ◆ check_config()

def palmmeteo_stdplugins.wrf.WRFRadPlugin.check_config | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

    (Load and) validate plugin-related configuration.

    Any plugin can optinally implement the check_config method for
    validating configuration. It is not required, so the method is not
    abstract.

Reimplemented from palmmeteo.plugins.Plugin.

## ◆ import_data()

def palmmeteo_stdplugins.wrf.WRFRadPlugin.import_data | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

Reimplemented from palmmeteo.plugins.ImportPluginMixin.

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/wrf.py